@@ -1,4 +1,4 @@
-/* $Id: nano.h,v 1.101 2003/04/19 19:34:05 astyanax Exp $ */
+/* $Id: nano.h,v 1.102 2003/08/04 02:51:12 astyanax Exp $ */
 /**************************************************************************
  *   nano.h                                                               *
  *                                                                        *
@@ -80,11 +80,11 @@
 #endif
 
 #ifndef HAVE_STRCASECMP
-#define strcasecmp strcmp
+#define strcasecmp nstricmp
 #endif
 
 #ifndef HAVE_STRNCASECMP
-#define strncasecmp strncmp
+#define strncasecmp nstrnicmp
 #endif
 
 /* HP-UX 10 & 11 do not seem to support KEY_HOME and KEY_END */
