@@ -1,4 +1,4 @@
-/* $Id: proto.h,v 1.121 2003/04/19 19:34:05 astyanax Exp $ */
+/* $Id: proto.h,v 1.122 2003/08/04 02:51:12 astyanax Exp $ */
 /**************************************************************************
  *   proto.h                                                              *
  *                                                                        *
@@ -399,6 +399,12 @@ void align(char **strp);
 void null_at(char **data, size_t index);
 void unsunder(char *str, size_t true_len);
 void sunder(char *str);
+#ifndef HAVE_STRCASECMP
+int nstricmp(const char *s1, const char *s2);
+#endif
+#ifndef HAVE_STRNCASECMP
+int nstrnicmp(const char *s1, const char *s2, size_t n);
+#endif
 #ifndef NANO_SMALL
 const char *revstrstr(const char *haystack, const char *needle,
 			const char *rev_start);
