@@ -1,4 +1,4 @@
-/* $Id: search.c,v 1.122 2003/04/15 01:15:09 astyanax Exp $ */
+/* $Id: search.c,v 1.123 2003/06/14 20:41:34 dolorous Exp $ */
 /**************************************************************************
  *   search.c                                                             *
  *                                                                        *
@@ -960,7 +960,7 @@ void insert_node(historytype *h, const char *s)
 {
     historytype *a;
 
-    a = nmalloc(sizeof(historytype));
+    a = (historytype *)nmalloc(sizeof(historytype));
     a->next = h->next;
     a->prev = h->next->prev;
     h->next->prev = a;
