@@ -1,4 +1,4 @@
-/* $Id: utils.c,v 1.54 2003/04/15 01:15:09 astyanax Exp $ */
+/* $Id: utils.c,v 1.56 2003/08/04 02:51:12 astyanax Exp $ */
 /**************************************************************************
  *   utils.c                                                              *
  *                                                                        *
@@ -66,8 +66,9 @@ int num_of_digits(int n)
 /* Fix the memory allocation for a string. */
 void align(char **strp)
 {
-    if (strp != NULL)
-	*strp = nrealloc(*strp, strlen(*strp) + 1);
+    assert(strp != NULL);
+    if (*strp != NULL)
+	*strp = charealloc(*strp, strlen(*strp) + 1);
 }
 
 /* Null a string at a certain index and align it. */
@@ -98,6 +99,37 @@ void sunder(char *str)
 	    *str = '\0';
 }
 
+#ifndef HAVE_STRCASECMP
+/* This function is equivalent to strcasecmp(). */
+int nstricmp(const char *s1, const char *s2)
+{
+    assert(s1 != NULL && s2 != NULL);
+    for (; *s1 != '\0' && *s2 != '\0'; s1++, s2++) {
+	if (tolower(*s1) != tolower(*s2))
+	    break;
+    }
+    return (tolower(*s1) - tolower(*s2));
+}
+#endif
+
+#ifndef HAVE_STRNCASECMP
+/* This function is equivalent to strncasecmp(). */
+int nstrnicmp(const char *s1, const char *s2, size_t n)
+{
+    assert(s1 != NULL && s2 != NULL);
+    for (; n > 0 && *s1 != '\0' && *s2 != '\0'; n--, s1++, s2++) {
+	if (tolower(*s1) != tolower(*s2))
+	    break;
+    }
+    if (n > 0)
+	return (tolower(*s1) - tolower(*s2));
+    else if (n == 0)
+	return 0;
+    else if (n < 0)
+	return -1;
+}
+#endif
+
 /* None of this is needed if we're using NANO_SMALL! */
 #ifndef NANO_SMALL
 const char *revstrstr(const char *haystack, const char *needle,
@@ -259,7 +291,7 @@ char *mallocstrcpy(char *dest, const char *src)
 /* Append a new magic-line to filebot. */
 void new_magicline(void)
 {
-    filebot->next = nmalloc(sizeof(filestruct));
+    filebot->next = (filestruct *)nmalloc(sizeof(filestruct));
     filebot->next->data = charalloc(1);
     filebot->next->data[0] = '\0';
     filebot->next->prev = filebot;
