@@ -1,4 +1,4 @@
-/* $Id: winio.c,v 1.178 2003/04/16 02:08:23 astyanax Exp $ */
+/* $Id: winio.c,v 1.183 2003/08/11 00:32:45 astyanax Exp $ */
 /**************************************************************************
  *   winio.c                                                              *
  *                                                                        *
@@ -87,7 +87,7 @@ size_t actual_x(const filestruct *fileptr, size_t xplus)
 	i--;
 
 #ifdef DEBUG
-    fprintf(stderr, _("actual_x for xplus=%d returns %d\n"), xplus, i);
+    fprintf(stderr, "actual_x for xplus=%d returns %d\n", xplus, i);
 #endif
 
     return i;
@@ -210,7 +210,15 @@ int nanogetstr(int allowtabs, const char *buf, const char *def,
     char *history = NULL;
     char *currentbuf = NULL;
     char *complete = NULL;
-    int last_kbinput = 0, ret2cb = 0;
+    int last_kbinput = 0;
+
+    /* This variable is used in the search history code.  use_cb == 0 
+       means that we're using the existing history and ignoring
+       currentbuf.  use_cb == 1 means that the entry in answer should be
+       moved to currentbuf or restored from currentbuf to answer. 
+       use_cb == 2 means that the entry in currentbuf should be moved to
+       answer or restored from answer to currentbuf. */
+    int use_cb = 0;
 #endif
     xend = strlen(def);
 
@@ -242,7 +250,7 @@ int nanogetstr(int allowtabs, const char *buf, const char *def,
     while ((kbinput = wgetch(bottomwin)) != 13) {
 	for (t = s; t != NULL; t = t->next) {
 #ifdef DEBUG
-	    fprintf(stderr, _("Aha! \'%c\' (%d)\n"), kbinput, kbinput);
+	    fprintf(stderr, "Aha! \'%c\' (%d)\n", kbinput, kbinput);
 #endif
 
 	    if (kbinput == t->val && kbinput < 32) {
@@ -361,16 +369,34 @@ int nanogetstr(int allowtabs, const char *buf, const char *def,
   do_upkey:
 	    if (history_list != NULL) {
 
-		/* If there's no previous temp holder, or if we already
-		   arrowed back down to it and (possibly edited it),
-		   update the holder */
-		if (currentbuf == NULL || (ret2cb == 1 && strcmp(currentbuf, answer))) {
+		/* if currentbuf is NULL, or if use_cb is 1, currentbuf
+		   isn't NULL, and currentbuf is different from answer,
+		   it means that we're scrolling up at the top of the
+		   search history, and we need to save the current
+		   answer in currentbuf; do this and reset use_cb to
+		   0 */
+		if (currentbuf == NULL || (use_cb == 1 && strcmp(currentbuf, answer))) {
 		    currentbuf = mallocstrcpy(currentbuf, answer);
-		    ret2cb = 0;
+		    use_cb = 0;
 		}
 
-		/* get older search from the history list */
-		if ((history = get_history_older(history_list)) != NULL) {
+		/* if currentbuf isn't NULL, use_cb is 2, and currentbuf 
+		   is different from answer, it means that we're
+		   scrolling up at the bottom of the search history, and
+		   we need to make the string in currentbuf the current
+		   answer; do this, blow away currentbuf since we don't
+		   need it anymore, and reset use_cb to 0 */
+		if (currentbuf != NULL && use_cb == 2 && strcmp(currentbuf, answer)) {
+		    answer = mallocstrcpy(answer, currentbuf);
+		    free(currentbuf);
+		    currentbuf = NULL;
+		    xend = strlen(answer);
+		    use_cb = 0;
+
+		/* else get older search from the history list and save
+		   it in answer; if there is no older search, blank out 
+		   answer */
+		} else if ((history = get_history_older(history_list)) != NULL) {
 		    answer = mallocstrcpy(answer, history);
 		    xend = strlen(history);
 		} else {
@@ -386,22 +412,41 @@ int nanogetstr(int allowtabs, const char *buf, const char *def,
 #ifndef NANO_SMALL
   do_downkey:
 	    if (history_list != NULL) {
-		/* get newer search from the history list */
+
+		/* get newer search from the history list and save it 
+		   in answer */
 		if ((history = get_history_newer(history_list)) != NULL) {
 		    answer = mallocstrcpy(answer, history);
 		    xend = strlen(history);
 
-		/* else if we ran out of history, regurgitate the temporary
-		   buffer and blow away currentbuf */
-		} else if (currentbuf != NULL) {
+		/* if there is no newer search, we're here */
+		
+		/* if currentbuf isn't NULL and use_cb isn't 2, it means 
+		   that we're scrolling down at the bottom of the search
+		   history and we need to make the string in currentbuf
+		   the current answer; do this, blow away currentbuf
+		   since we don't need it anymore, and set use_cb to
+		   1 */
+		} else if (currentbuf != NULL && use_cb != 2) {
 		    answer = mallocstrcpy(answer, currentbuf);
 		    free(currentbuf);
 		    currentbuf = NULL;
 		    xend = strlen(answer);
-		    ret2cb = 1;
-		} else {
-		    answer = mallocstrcpy(answer, "");
+		    use_cb = 1;
+
+		/* otherwise, if currentbuf is NULL and use_cb isn't 2, 
+		   it means that we're scrolling down at the bottom of
+		   the search history and the current answer (if it's
+		   not blank) needs to be saved in currentbuf; do this,
+		   blank out answer (if necessary), and set use_cb to
+		   2 */
+		} else if (use_cb != 2) {
+		    if (answer[0] != '\0') {
+			currentbuf = mallocstrcpy(currentbuf, answer);
+			answer = mallocstrcpy(answer, "");
+		    }
 		    xend = 0;
+		    use_cb = 2;
 		}
 		x = xend;
 	    }
@@ -443,6 +488,12 @@ int nanogetstr(int allowtabs, const char *buf, const char *def,
 		    if (x > 0)
 			x--;
 		    break;
+		case 'F':
+		    x = xend;
+		    break;
+		case 'H':
+		    x = 0;
+		    break;
 		case '1':
 		case '7':
 		    x = 0;
@@ -470,7 +521,7 @@ int nanogetstr(int allowtabs, const char *buf, const char *def,
 
 		for (t = s; t != NULL; t = t->next) {
 #ifdef DEBUG
-		    fprintf(stderr, _("Aha! \'%c\' (%d)\n"), kbinput,
+		    fprintf(stderr, "Aha! \'%c\' (%d)\n", kbinput,
 			    kbinput);
 #endif
 		    if (kbinput == t->val || kbinput == t->val - 32)
@@ -486,14 +537,14 @@ int nanogetstr(int allowtabs, const char *buf, const char *def,
 	default:
 	    if (kbinput < 32)
 		break;
-	    answer = nrealloc(answer, xend + 2);
+	    answer = charealloc(answer, xend + 2);
 	    memmove(answer + x + 1, answer + x, xend - x + 1);
 	    xend++;
 	    answer[x] = kbinput;
 	    x++;
 
 #ifdef DEBUG
-	    fprintf(stderr, _("input \'%c\' (%d)\n"), kbinput, kbinput);
+	    fprintf(stderr, "input \'%c\' (%d)\n", kbinput, kbinput);
 #endif
 	} /* switch (kbinput) */
 #ifndef NANO_SMALL
@@ -1061,7 +1112,7 @@ void update_cursor(void)
     int i = 0;
 
 #ifdef DEBUG
-    fprintf(stderr, _("Moved to (%d, %d) in edit buffer\n"), current_y,
+    fprintf(stderr, "Moved to (%d, %d) in edit buffer\n", current_y,
 	    current_x);
 #endif
 
@@ -1212,7 +1263,7 @@ int statusq(int tabs, const shortcut *s, const char *def,
     blank_statusbar();
 
 #ifdef DEBUG
-    fprintf(stderr, _("I got \"%s\"\n"), answer);
+    fprintf(stderr, "I got \"%s\"\n", answer);
 #endif
 
 #ifndef DISABLE_TABCOMP
@@ -1495,7 +1546,7 @@ int line_len(const char *ptr)
 int do_help(void)
 {
 #ifndef DISABLE_HELP
-    int i, page = 0, kbinput = 0, no_more = 0, kp, kp2;
+    int i, page = 0, kbinput = 0, no_more = 0, kp;
     int no_help_flag = 0;
     const shortcut *oldshortcut;
 
@@ -1513,7 +1564,6 @@ int do_help(void)
     currshortcut = help_list;
 
     kp = keypad_on(edit, 1);
-    kp2 = keypad_on(bottomwin, 1);
 
     if (ISSET(NO_HELP)) {
 
@@ -1615,7 +1665,6 @@ int do_help(void)
     curs_set(1);
     edit_refresh();
     kp = keypad_on(edit, kp);
-    kp2 = keypad_on(bottomwin, kp2);
 
     /* The help_init() at the beginning allocated help_text, which has
        now been written to screen. */
@@ -1701,11 +1750,11 @@ void fix_editbot(void)
 /* Dump the current file structure to stderr */
 void dump_buffer(const filestruct *inptr) {
     if (inptr == fileage)
-	fprintf(stderr, _("Dumping file buffer to stderr...\n"));
+	fprintf(stderr, "Dumping file buffer to stderr...\n");
     else if (inptr == cutbuffer)
-	fprintf(stderr, _("Dumping cutbuffer to stderr...\n"));
+	fprintf(stderr, "Dumping cutbuffer to stderr...\n");
     else
-	fprintf(stderr, _("Dumping a buffer to stderr...\n"));
+	fprintf(stderr, "Dumping a buffer to stderr...\n");
 
     while (inptr != NULL) {
 	fprintf(stderr, "(%d) %s\n", inptr->lineno, inptr->data);
